<?php

namespace LiamW\CustomEditorColors\Admin\Controller;

use LiamW\CustomEditorColors\Entity\EditorColor;
use XF\Admin\Controller\AbstractController;
use XF\Mvc\ParameterBag;

class EditorColors extends AbstractController
{
	public function actionIndex()
	{
		$colors = $this->finder('LiamW\CustomEditorColors:EditorColor')->order('display_order')->fetch();

		$viewParams = [
			'colors' => $colors
		];

		return $this->view('LiamW\CustomEditorColors:EditorColors\List', 'liamw_customeditorcolors_color_list', $viewParams);
	}

	protected function colorAddEdit(EditorColor $color)
	{
		$viewParams = [
			'color' => $color
		];

		return $this->view('LiamW\CustomEditorColors:EditorColors\Edit', 'liamw_customeditorcolors_color_edit', $viewParams);
	}

	public function actionAdd()
	{
		$color = $this->em()->create('LiamW\CustomEditorColors:EditorColor');

		return $this->colorAddEdit($color);
	}

	public function actionEdit(ParameterBag $params)
	{
		$color = $this->assertEditorColorExists($params['color_hex']);

		return $this->colorAddEdit($color);
	}

	public function colorSaveProcess(EditorColor $color)
	{
		$form = $this->formAction();

		$input = $this->filter([
			'color_hex' => 'str',
			'display_order' => 'uint',
			'active' => 'bool'
		]);

		$form->basicEntitySave($color, $input);

		return $form;
	}

	public function actionSave(ParameterBag $params)
	{
		$this->assertPostOnly();

		if ($params['color_hex'])
		{
			$color = $this->assertEditorColorExists($params['color_hex']);
		}
		else
		{
			$color = $this->em()->create('LiamW\CustomEditorColors:EditorColor');
		}

		$this->colorSaveProcess($color)->run();

		return $this->redirect($this->buildLink('editor-colors'));
	}

	public function actionToggle(ParameterBag $params)
	{
		$this->toggleProcess('LiamW\CustomEditorColors:EditorColor');

		return $this->message(\XF::phrase('your_changes_have_been_saved'));
	}

	public function actionDelete(ParameterBag $params)
	{
		$color = $this->assertEditorColorExists($params['color_hex']);

		if ($this->isPost())
		{
			$color->delete();

			return $this->redirect($this->buildLink('editor-colors'));
		}
		else
		{
			$viewParams = [
				'color' => $color
			];

			return $this->view('LiamW\CustomEditorColors:EditorColors\Delete', 'liamw_customeditorcolors_color_delete', $viewParams);
		}
	}

	protected function assertEditorColorExists($colorHex)
	{
		return $this->assertRecordExists('LiamW\CustomEditorColors:EditorColor', $colorHex);
	}
}